@@ -19,14 +19,16 @@ class Mine:
     _token_creation_time: float
     _expiration_time: int
 
-    def __init__(self, es_request: EsRequest, host: str = Config.host):
+    def __init__(self, es_request: EsRequest):
         """
         Initialize the MINE object.
 
-        :param host: the endpoint of the REST API
-        :param es_request: the object containing request information to Elasticsearch
+        Parameters
+        ----------
+        es_request : EsRequest
+            the object containing request information to Elasticsearch
         """
-        self._host = host
+        self._host = Config.host
         self._es_request = es_request
         self._device_code = ''
         self._user_code = ''
@@ -55,6 +57,7 @@ class Mine:
 
         payload = {
             'q': self._es_request.search_term,
+            'r[]': self._es_request.resources,
             'f[]': self._es_request.filters,
             'a': self._es_request.aggregation,
             'p': self._es_request.page,
