@@ -5,6 +5,27 @@ from minetext import EsRequest, Mine
 
 class TestSearch:
 
+    def test_search(self):
+        """
+        Test a simple search query.
+        """
+        es_request = EsRequest(search_term='*')
+        mine = Mine(es_request)
+        response = mine.search()
+        assert response.took is not None
+
+    def test_search_resource(self):
+        """
+        Test the search method on a specific resource
+        """
+        es_request = EsRequest(search_term='*', resources=['tda'])
+        mine = Mine(es_request)
+        response = mine.search()
+
+        # Make sure that the response only from the tda index
+        for hit in response:
+            assert 'tda' in hit.meta.index
+
     def test_search_with_term_y_input(self, monkeypatch):
         """When user assures they signed in but did not.
 
@@ -38,6 +59,5 @@ class TestSearch:
         assert response.success()
 
         # Make sure that it doesn't return the content
-        for hit in response['hits']['hits']:
-            if 'content' in hit['_source']:
-                assert False
+        for hit in response:
+            assert not hasattr(hit, 'content')
